summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/umlviewimageexportermodel.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/umlviewimageexportermodel.h')
-rw-r--r--umbrello/umbrello/umlviewimageexportermodel.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/umbrello/umbrello/umlviewimageexportermodel.h b/umbrello/umbrello/umlviewimageexportermodel.h
index d69796ac..1517d2d0 100644
--- a/umbrello/umbrello/umlviewimageexportermodel.h
+++ b/umbrello/umbrello/umlviewimageexportermodel.h
@@ -12,8 +12,8 @@
#ifndef UMLVIEWIMAGEEXPORTERMODEL_H
#define UMLVIEWIMAGEEXPORTERMODEL_H
-#include <qstringlist.h>
-#include <qrect.h>
+#include <tqstringlist.h>
+#include <tqrect.h>
// forward declarations
class UMLView;
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
public:
/**
* Returns a QStringList containing all the supported image types to use when exporting.
* All the types will be lower case.
*
* @return A QStringList containing all the supported image types to use when exporting.
*/
- static QStringList supportedImageTypes();
+ static TQStringList supportedImageTypes();
/**
* Returns a QStringList containing all the supported mime types to use when exporting.
* All the types will be lower case.
*
* @return A QStringList containing all the supported mime types to use when exporting.
*/
- static QStringList supportedMimeTypes();
+ static TQStringList supportedMimeTypes();
/**
* Returns the mime type for an image type.
* The supported image types are those that the diagrams can be exported to.
*
* @param imageType The type of the image.
* @return A QString with the equivalent mime type, or QString::null if
* it's unknown.
*/
- static QString imageTypeToMimeType(const QString& imageType);
+ static TQString imageTypeToMimeType(const TQString& imageType);
/**
* Returns the image type for a mime type.
* The supported image types are those that the diagrams can be exported to.
*
* @param mimeType The mime type.
* @return A lowercase QString with the equivalent image type, or QString::null
* if it's unknown.
*/
- static QString mimeTypeToImageType(const QString& mimeType);
+ static TQString mimeTypeToImageType(const TQString& mimeType);
/**
* Constructor for UMLViewImageExporterModel.
@@ -102,10 +102,10 @@ public:
* @param directory The url of the directory where the images will be saved.
* @param useFolders If the tree structure of the views in the document must be created
* in the target directory.
* @return A QStringList with all the error messages that occurred during export.
* If the list is empty, all the views were exported successfully.
*/
- QStringList exportAllViews(const QString &imageType, const KURL &directory, bool useFolders) const;
+ TQStringList exportAllViews(const TQString &imageType, const KURL &directory, bool useFolders) const;
/**
* Exports the view to the url using the 'imageType' for the image.
@@ -120,9 +120,9 @@ public:
* @param imageType The type of the image the view will be exported to.
* @param url The url where the image will be saved.
* @return The message error if some problem occurred when exporting, or
* QString::null if all went fine.
*/
- QString exportView(UMLView* view, const QString &imageType, const KURL &url) const;
+ TQString exportView(UMLView* view, const TQString &imageType, const KURL &url) const;
private:
@@ -142,7 +142,7 @@ private:
* in the file name.
* @return The name of the file where the view will be exported to.
*/
- QString getDiagramFileName(UMLView *view, const QString &imageType, bool useFolders = false) const;
+ TQString getDiagramFileName(UMLView *view, const TQString &imageType, bool useFolders = false) const;
/**
* Creates, if it doesn't exist, the directory to save the file.
@@ -163,7 +163,7 @@ private:
* @return True if the operation was successful,
* false if a problem occurred while exporting.
*/
- bool exportViewTo(UMLView* view, const QString &imageType, const QString &fileName) const;
+ bool exportViewTo(UMLView* view, const TQString &imageType, const TQString &fileName) const;
/**
* Exports the view to the file 'fileName' as EPS.
@@ -175,7 +175,7 @@ private:
* @return True if the operation was successful,
* false if a problem occurred while exporting.
*/
- bool exportViewToEps(UMLView* view, const QString &fileName, bool isEPS) const;
+ bool exportViewToEps(UMLView* view, const TQString &fileName, bool isEPS) const;
/**
* Fix the file 'fileName' to be a valid EPS containing the
@@ -185,7 +185,7 @@ private:
* @return True if the operation was successful,
* false if a problem occurred while exporting.
*/
- bool fixEPS(const QString &fileName, const QRect& rect) const;
+ bool fixEPS(const TQString &fileName, const TQRect& rect) const;
/**
* Exports the view to the file 'fileName' as SVG.
@@ -195,11 +195,11 @@ private:
* @return True if the operation was successful,
* false if a problem occurred while exporting.
*/
- bool exportViewToSvg(UMLView* view, const QString &fileName) const;
+ bool exportViewToSvg(UMLView* view, const TQString &fileName) const;
/**
* Exports the view to the file 'fileName' as a pixmap of the specified type.
- * The valid types are those supported by QPixmap save method.
+ * The valid types are those supported by TQPixmap save method.
*
* @param view The view to export.
* @param imageType The type of the image the view will be exported to.
@@ -207,7 +207,7 @@ private:
* @return True if the operation was successful,
* false if a problem occurred while exporting.
*/
- bool exportViewToPixmap(UMLView* view, const QString &imageType, const QString &fileName) const;
+ bool exportViewToPixmap(UMLView* view, const TQString &imageType, const TQString &fileName) const;
};
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
public:
/**
- * Returns a QStringList containing all the supported image types to use when exporting.
+ * Returns a TQStringList containing all the supported image types to use when exporting.
* All the types will be lower case.
*
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
* All the types will be lower case.
*
- * @return A QStringList containing all the supported image types to use when exporting.
+ * @return A TQStringList containing all the supported image types to use when exporting.
*/
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
/**
- * Returns a QStringList containing all the supported mime types to use when exporting.
+ * Returns a TQStringList containing all the supported mime types to use when exporting.
* All the types will be lower case.
*
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
* All the types will be lower case.
*
- * @return A QStringList containing all the supported mime types to use when exporting.
+ * @return A TQStringList containing all the supported mime types to use when exporting.
*/
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
*
* @param imageType The type of the image.
- * @return A QString with the equivalent mime type, or QString::null if
+ * @return A TQString with the equivalent mime type, or TQString::null if
* it's unknown.
*/
@@ -36,40 +36,40 @@ class UMLViewImageExporterModel {
*
* @param mimeType The mime type.
- * @return A lowercase QString with the equivalent image type, or QString::null
+ * @return A lowercase TQString with the equivalent image type, or TQString::null
* if it's unknown.
*/
@@ -102,10 +102,10 @@ public:
* @param useFolders If the tree structure of the views in the document must be created
* in the target directory.
- * @return A QStringList with all the error messages that occurred during export.
+ * @return A TQStringList with all the error messages that occurred during export.
* If the list is empty, all the views were exported successfully.
*/
@@ -120,9 +120,9 @@ public:
* @param url The url where the image will be saved.
* @return The message error if some problem occurred when exporting, or
- * QString::null if all went fine.
+ * TQString::null if all went fine.
*/